You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@opendal.apache.org by "silver-ymz (via GitHub)" <gi...@apache.org> on 2023/08/06 13:13:07 UTC

[GitHub] [incubator-opendal] silver-ymz opened a new pull request, #2792: ci: use cache to speed up haskell ci

silver-ymz opened a new pull request, #2792:
URL: https://github.com/apache/incubator-opendal/pull/2792

   (no comment)


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: commits-unsubscribe@opendal.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org


[GitHub] [incubator-opendal] silver-ymz commented on pull request #2792: ci: use cache to speed up haskell ci

Posted by "silver-ymz (via GitHub)" <gi...@apache.org>.
silver-ymz commented on PR #2792:
URL: https://github.com/apache/incubator-opendal/pull/2792#issuecomment-1666864750

   With caching, haskell ci time has been reduced from 10 minutes to 5 minutes.


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: commits-unsubscribe@opendal.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org


[GitHub] [incubator-opendal] Xuanwo merged pull request #2792: ci: use cache to speed up haskell ci

Posted by "Xuanwo (via GitHub)" <gi...@apache.org>.
Xuanwo merged PR #2792:
URL: https://github.com/apache/incubator-opendal/pull/2792


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: commits-unsubscribe@opendal.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org